Exception: BrightData::ArgumentError

Inherits:
Error
  • Object
show all
Defined in:
lib/brightdata/errors.rb

Overview

Raised when a caller passes an invalid argument shape or value.

This class intentionally inherits from Error, not from ‘::ArgumentError`. Use `rescue BrightData::ArgumentError` or `rescue BrightData::Error`.